#
# This file generates the sidebar/toctree for all TileDB projects and should
# be copied to each project when it is updated.
#
# This file is originally from the RobotPy documentation project https://github.com/robotpy/robotpy-docs, licensed under
#

import os

def write_if_changed(fname, contents):

    try:
        with open(fname, 'r') as fp:
            old_contents = fp.read()
    except:
        old_contents = ''

    if old_contents != contents:
        with open(fname, 'w') as fp:
            fp.write(contents)

def generate_sidebar(conf, conf_api):

    version = conf['rtd_version']

    lines = [
        '', '.. DO NOT MODIFY! THIS PAGE IS AUTOGENERATED!', ''
    ]

    url_base = 'https://docs.tiledb.io'
    lang = 'en'

    def toctree(name):
        lines.extend(['.. toctree::',
                      '    :caption: %s' % name,
                      '    :maxdepth: 1',
                      ''])

    def endl():
        lines.append('')

    def write(desc, link):
        if conf_api == 'tiledb':
            args = desc, link
        else:
            args = desc, '%s/%s/%s/%s.html' % (url_base, lang, version, link)

        lines.append('    %s <%s>' % args)

    def write_api(project, desc, rst_page):
        # From non-root project to root project link
        if project == 'tiledb' and conf_api != 'tiledb':
            args = desc, url_base, lang, version, rst_page
            lines.append('    %s API <%s/%s/%s/%s.html>' % args)
        # From anything to non-root project link
        elif project != conf_api:
            args = desc, url_base, project, lang, version, rst_page
            lines.append('    %s API <%s/projects/%s/%s/%s/%s.html>' % args)
        # Local project link
        else:
            args = desc, rst_page
            lines.append('    %s API <%s>' % args)

    #
    # Specify the sidebar contents here
    #

    toctree('Getting Started')
    write('Introduction', 'introduction')
    write('Installation', 'installation')
    write('Usage', 'usage')
    endl()

    toctree('API Reference')
    write_api('tiledb', 'C', 'c-api')
    write_api('tiledb', 'C++', 'c++-api')
    write_api('tiledb-py', 'Python', 'python-api')
    endl()

    toctree('TileDB 101')
    write('Data Model', 'tiledb101/data-model')
    write('Basic Concepts', 'tiledb101/basic-concepts')
    write('System Architecture', 'tiledb101/system-architecture')
    write('Physical Organization', 'tiledb101/physical-organization')
    write('Writing', 'tiledb101/writing/index')
    write('Updating', 'tiledb101/updating')
    write('Consolidation', 'tiledb101/consolidation')
    write('Reading', 'tiledb101/reading/index')
    write('Compression', 'tiledb101/compression')
    write('Asynchronous I/O', 'tiledb101/asynchronous-io')
    write('Key-Value Store', 'tiledb101/key-value-store')
    write('Object Management', 'tiledb101/object-management')
    write('Storage Backends', 'tiledb101/storage-backends')
    write('Virtual Filesystem', 'tiledb101/virtual-filesystem')
    write('Language Bindings', 'tiledb101/language-bindings')
    write('Concurrency', 'tiledb101/concurrency')
    write('Consistency', 'tiledb101/consistency')
    endl()

    write_if_changed('_sidebar.rst.inc', '\n'.join(lines))
